;;
;; This is a cushion module to use R7RS (scheme lazy) from Gauche
;;
(define-module scheme.lazy (use r7rs-setup))
